@@ -36,8 +36,8 @@ fn output_of(num_or_wire: &str, gates: &mut HashMap<&str, Gate>) -> Option<Signa
 
 fn find_output(wire: &str, gates: &mut HashMap<&str, Gate>) -> Option<SignalValue> {
     let gate = gates.get(wire)?;
-    if let Some(value) = gate.computed_value {
-        Some(value)
+    if gate.computed_value.is_some() {
+        gate.computed_value
     } else {
         let signal_value = match gate.operation {
             Operation::Assign(value) => output_of(value, gates)?,
@@ -48,7 +48,7 @@ fn find_output(wire: &str, gates: &mut HashMap<&str, Gate>) -> Option<SignalValu
             Operation::RightShift(lhs, rhs) => output_of(lhs, gates)? >> output_of(rhs, gates)?,
         };
 
-        gates.get_mut(wire).unwrap().computed_value = Some(signal_value);
+        gates.get_mut(wire)?.computed_value = Some(signal_value);
         Some(signal_value)
     }
 }
