@@ -108,7 +108,7 @@ fn identify_char(input: &str) -> Result<char, String> {
             println!("###Unrecognized string:\n{}###", input);
             let mut shower = String::new();
             shower.push('"');
-            shower.push_str(&input.replace("\n", "\\n"));
+            shower.push_str(&input.replace('\n', "\\n"));
             shower.push_str("\" => '?',");
             println!("Shower:\n{}", shower);
             return Err(format!("Unrecognized char: {}", input));
